import unittest
from datetime import datetime
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

from embedin.model.embedding_model import Base, EmbeddingModel

engine = create_engine("sqlite:///:memory:", echo=True)
Session = sessionmaker(bind=engine)


class EmbeddingModelTestCase(unittest.TestCase):
    def setUp(self):
        Base.metadata.create_all(engine)
        self.session = Session()

        self.embedding = EmbeddingModel(
            id="123",
            collection_id="abc",
            text="sample text",
            embedding_data={"sample": [1, 2, 3]},
            meta_data={"created_by": "user1"},
            hash="1234",
            created_at=datetime.now(),
        )
        self.session.add(self.embedding)
        self.session.commit()

    def tearDown(self):
        self.session.rollback()
        self.session.close()
        Base.metadata.drop_all(engine)

    def test_embedding_model(self):
        embedding = self.session.query(EmbeddingModel).first()

        self.assertIsNotNone(embedding)
        self.assertEqual(embedding.id, "123")
        self.assertEqual(embedding.collection_id, "abc")
        self.assertEqual(embedding.text, "sample text")
        self.assertEqual(embedding.embedding_data, {"sample": [1, 2, 3]})
        self.assertEqual(embedding.meta_data, {"created_by": "user1"})
        self.assertEqual(embedding.hash, "1234")
        self.assertIsInstance(embedding.created_at, datetime)

        # Try to add another embedding model with the same hash (should fail due to unique constraint)
        duplicate_embedding = EmbeddingModel(
            id="2",
            collection_id="3",
            text="other text",
            embedding_data={"data": [4, 5, 6]},
            meta_data={"meta": "data"},
            hash="1234",
            created_at=datetime.now(),
        )
        self.session.add(duplicate_embedding)
        with self.assertRaises(Exception):
            self.session.commit()


if __name__ == "__main__":
    unittest.main()
